@@ -32,12 +32,13 @@
 #' 
 #' @author Gianluca Baio
 #' @seealso \code{\link{bcea}}
-#' @references
-#' Baio, G., Dawid, A. P. (2011). Probabilistic Sensitivity
-#' Analysis in Health Economics. Statistical Methods in Medical Research
-#' doi:10.1177/0962280211419832.
+#' @importFrom Rdpack reprompt
 #' 
-#' Baio G. (2012). Bayesian Methods in Health Economics. CRC/Chapman Hall, London.
+#' @references
+#' 
+#' \insertRef{Baio2011}{BCEA}
+#' 
+#' \insertRef{Baio2013}{BCEA}
 #' 
 #' @export
 #' 
@@ -45,15 +46,15 @@
 #' 
 #' \dontrun{
 #'   data(Vaccine, package = "BCEA")
-#'   m <- bcea(e, c, ref = 2)
+#'   m <- bcea(eff, cost, ref = 2)
 #'   make.report(m)
 #' }
 #' 
-make.report = function(he,
-                       evppi = NULL,
-                       ext = "pdf",
-                       echo = FALSE,
-                       ...) {
+make.report <- function(he,
+                        evppi = NULL,
+                        ext = "pdf",
+                        echo = FALSE,
+                        ...) {
   
   # check if knitr installed (and if not, asks for it)
   if(!isTRUE(requireNamespace("knitr", quietly = TRUE))) {
@@ -123,6 +124,7 @@ make.report = function(he,
 
 #' Allow disabling of the cat messages
 #' @param x Object to quietly return
+#' @keywords internal
 #' 
 quiet <- function(x) { 
   sink(tempfile()) 
@@ -133,6 +135,7 @@ quiet <- function(x) {
 #' Automatically open pdf output using default pdf viewer
 #' 
 #' @param file_name String file names for pdf
+#' @keywords internal
 #' 
 openPDF <- function(file_name) {
   os <- .Platform$OS.type
